#[non_exhaustive]
pub enum Request { Destroy, GetOutput { id: New<WpColorManagementOutputV1>, output: WlOutput, }, GetSurface { id: New<WpColorManagementSurfaceV1>, surface: WlSurface, }, GetSurfaceFeedback { id: New<WpColorManagementSurfaceFeedbackV1>, surface: WlSurface, }, CreateIccCreator { obj: New<WpImageDescriptionCreatorIccV1>, }, CreateParametricCreator { obj: New<WpImageDescriptionCreatorParamsV1>, }, CreateWindowsScrgb { image_description: New<WpImageDescriptionV1>, }, GetImageDescription { image_description: New<WpImageDescriptionV1>, reference: WpImageDescriptionReferenceV1, }, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Destroy

destroy the color manager

Destroy the wp_color_manager_v1 object. This does not affect any other objects in any way.

This is a destructor, once received this object cannot be used any longer.



GetOutput

create a color management interface for a wl_output

This creates a new wp_color_management_output_v1 object for the given wl_output.

See the wp_color_management_output_v1 interface for more details.

Fields

output: WlOutput


GetSurface

create a color management interface for a wl_surface

If a wp_color_management_surface_v1 object already exists for the given wl_surface, the protocol error surface_exists is raised.

This creates a new color wp_color_management_surface_v1 object for the given wl_surface.

See the wp_color_management_surface_v1 interface for more details.

Fields

surface: WlSurface


GetSurfaceFeedback

create a color management feedback interface

This creates a new color wp_color_management_surface_feedback_v1 object for the given wl_surface.

See the wp_color_management_surface_feedback_v1 interface for more details.

Fields

surface: WlSurface


CreateIccCreator

make a new ICC-based image description creator object

Makes a new ICC-based image description creator object with all properties initially unset. The client can then use the object’s interface to define all the required properties for an image description and finally create a wp_image_description_v1 object.

This request can be used when the compositor advertises wp_color_manager_v1.feature.icc_v2_v4. Otherwise this request raises the protocol error unsupported_feature.

Fields

obj: New<WpImageDescriptionCreatorIccV1>

the new creator object



CreateParametricCreator

make a new parametric image description creator object

Makes a new parametric image description creator object with all properties initially unset. The client can then use the object’s interface to define all the required properties for an image description and finally create a wp_image_description_v1 object.

This request can be used when the compositor advertises wp_color_manager_v1.feature.parametric. Otherwise this request raises the protocol error unsupported_feature.

Fields

obj: New<WpImageDescriptionCreatorParamsV1>

the new creator object



CreateWindowsScrgb

create Windows-scRGB image description object

This creates a pre-defined image description for the so-called Windows-scRGB stimulus encoding. This comes from the Windows 10 handling of its own definition of an scRGB color space for an HDR screen driven in BT.2100/PQ signalling mode.

Windows-scRGB uses sRGB (BT.709) color primaries and white point. The transfer characteristic is extended linear.

The nominal color channel value range is extended, meaning it includes negative and greater than 1.0 values. Negative values are used to escape the sRGB color gamut boundaries. To make use of the extended range, the client needs to use a pixel format that can represent those values, e.g. floating-point 16 bits per channel.

Nominal color value R=G=B=0.0 corresponds to BT.2100/PQ system 0 cd/m², and R=G=B=1.0 corresponds to BT.2100/PQ system 80 cd/m². The maximum is R=G=B=125.0 corresponding to 10k cd/m².

Windows-scRGB is displayed by Windows 10 by converting it to BT.2100/PQ, maintaining the CIE 1931 chromaticity and mapping the luminance as above. No adjustment is made to the signal to account for the viewing conditions.

The reference white level of Windows-scRGB is unknown. If a reference white level must be assumed for compositor processing, it should be R=G=B=2.5375 corresponding to 203 cd/m² of Report ITU-R BT.2408-7.

The target color volume of Windows-scRGB is unknown. The color gamut may be anything between sRGB and BT.2100.

Note: EGL_EXT_gl_colorspace_scrgb_linear definition differs from Windows-scRGB by using R=G=B=1.0 as the reference white level, while Windows-scRGB reference white level is unknown or varies. However, it seems probable that Windows implements both EGL_EXT_gl_colorspace_scrgb_linear and Vulkan VK_COLOR_SPACE_EXTENDED_SRGB_LINEAR_EXT as Windows-scRGB.

This request can be used when the compositor advertises wp_color_manager_v1.feature.windows_scrgb. Otherwise this request raises the protocol error unsupported_feature.

The resulting image description object does not allow get_information request. The wp_image_description_v1.ready event shall be sent.

Fields

image_description: New<WpImageDescriptionV1>


GetImageDescription

create an image description from a reference

This request retrieves the image description backing a reference.

The get_information request can be used if and only if the request that creates the reference allows it.

Only available since version 2 of the interface

Fields

image_description: New<WpImageDescriptionV1>

Implementations



impl Request

pub fn opcode(&self) -> u16

Get the opcode number of this message