Struct WpColorManagerV1
pub struct WpColorManagerV1 { /* private fields */ }wayland and Linux only.Expand description
color manager singleton
A singleton global interface used for getting color management extensions for wl_surface and wl_output objects, and for creating client defined image description objects. The extension interfaces allow getting the image description of outputs and setting the image description of surfaces.
Compositors should never remove this global.
See also the Request enum for this interface.
Implementations
impl WpColorManagerV1
impl WpColorManagerV1
pub fn supported_intent(&self, render_intent: RenderIntent)
pub fn supported_intent(&self, render_intent: RenderIntent)
supported rendering intent
When this object is created, it shall immediately send this event once for each rendering intent the compositor supports.
A compositor must not advertise intents that are deprecated in the bound version of the interface.
pub fn supported_feature(&self, feature: Feature)
pub fn supported_feature(&self, feature: Feature)
supported features
When this object is created, it shall immediately send this event once for each compositor supported feature listed in the enumeration.
A compositor must not advertise features that are deprecated in the bound version of the interface.
pub fn supported_tf_named(&self, tf: TransferFunction)
pub fn supported_tf_named(&self, tf: TransferFunction)
supported named transfer characteristic
When this object is created, it shall immediately send this event once for each named transfer function the compositor supports with the parametric image description creator.
A compositor must not advertise transfer functions that are deprecated in the bound version of the interface.
pub fn supported_primaries_named(&self, primaries: Primaries)
pub fn supported_primaries_named(&self, primaries: Primaries)
supported named primaries
When this object is created, it shall immediately send this event once for each named set of primaries the compositor supports with the parametric image description creator.
A compositor must not advertise names that are deprecated in the bound version of the interface.
pub fn done(&self)
pub fn done(&self)
all features have been sent
This event is sent when all supported rendering intents, features, transfer functions and named primaries have been sent.